<?php
/* Copyright (C) 2010      Denis Martin		<denimartin@hotmail.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * or see http://www.gnu.org/
 */

/**
 *	\file       htdocs/lib/productdiscount.lib.php
 *	\brief      Librairy of function for the ProductDiscount module
 * 	\ingroup	product
 *	\version    $Id: productdiscount.lib.php,v 0.1 2010/02/10 17:42:31 dmartin Exp $
 *
 */

require_once(DOL_DOCUMENT_ROOT."/productdiscount.class.php") ;

/**
 * Function to get customer-associated product discounts.
 * @param Societe $societe Customer for which the function gets product discounts
 * @return array list of ProductDiscount objects
 */
function get_product_discount_from_customer($societe)
{
	global $db ;
	$array_product_discount = array() ;
	
	// Get id of productdiscounts and customer related to this product
	$query = 
	"SELECT pd.rowid " .
	" FROM llx_product_discount as pd " .
	" WHERE pd.fk_customer = " . $societe->id ;
	
	dol_syslog("get_product_discount_from_customer() : " . $query, LOG_DEBUG) ;
	
	$resql = $db->query($query) ;
	
	//Fetch product discounts and add it to the array
	if($resql)
	{
		$num = $db->num_rows($resql);
		if ($num)
		{
			$i = 0;
			while ($i < $num)
			{
				$obj = $db->fetch_object($resql);
				if ($obj)
				{
					$array_product_discount[$i] = new ProductDiscount($db, $obj->rowid) ;
				}
				$i++;
			}
		}
	}
	else
	{
		dol_syslog("Erreur requete : " . $query, LOG_ERR) ;
	}
	
	
	return $array_product_discount ;
	}

/**
 * Function to get product-associated product discounts.
 * @param Product $product Product for which the function gets product discounts
 * @return array Array list of ProductDiscount objects
 */
function get_product_discount_from_product($product)
{
	global $db ;
	$array_product_discount = array() ;
	
	// Get id of productdiscounts and customer related to this product
	$query = 
	"SELECT pd.rowid " .
	" FROM llx_product_discount as pd " .
	" WHERE pd.fk_product = " . $product->id ;
	
	dol_syslog("get_product_discount_from_product() : " . $query, LOG_DEBUG) ;
	
	$resql = $db->query($query) ;
	
	//Fetch product discounts and add it to the array
	if($resql)
	{
		$num = $db->num_rows($resql);
		if ($num)
		{
			$i = 0;
			while ($i < $num)
			{
				$obj = $db->fetch_object($resql);
				if ($obj)
				{
					$array_product_discount[] = new ProductDiscount($db, $obj->rowid) ;
				}
				$i++;
			}
		}
	}
	else
	{
		dol_syslog("Erreur requete : " . $query, LOG_ERR) ;
	}
	
	return $array_product_discount ;
}
?>
