<?php
/* Copyright (C) 2007-2008 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2010 Denis Martin	<denimartin@hotmail.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *      \file       htdocs/productdiscount/productdiscount.class.php
 *      \ingroup    productdiscount
 *      \brief      CRUD Class for managing product discounts (Create/Read/Update/Delete)
 *		\version    $Id: productdiscount.class.php,v 1.0 2010/02/17 dmartin Exp $
 *		\author		Denis Martin
 *		\remarks	Initialy built by build_class_from_table on 2010-02-17 10:18
 */

// Put here all includes required by your class file
require_once(DOL_DOCUMENT_ROOT."/commonobject.class.php");
require_once(DOL_DOCUMENT_ROOT."/societe.class.php");
require_once(DOL_DOCUMENT_ROOT."/product.class.php");


/**
 *      \class      ProductDiscount
 *      \brief      CRUD class for managing product_discounts in db
 *		\remarks	Initialy built by build_class_from_table on 2010-02-17 10:18
 */
class ProductDiscount // extends CommonObject
{
	var $db;							//!< To store db handler
	var $error;							//!< To return error code (or message)
	var $errors=array();				//!< To return several error codes (or messages)
	//var $element='product_discount';			//!< Id that identify managed objects
	//var $table_element='product_discount';	//!< Name of table without prefix where object is stored
    
    var $id;
    
	var $fk_customer;
	var $fk_product;
	var $discount;
	var $price;
	var $price_base_type;

    
    
    
    /**
     *      \brief      Constructor
     *      \param      DB      Database handler
     *      \param		rowid	id of the ProductDiscount to load
     *      \return		1 if success, -1 if error
     */
    function ProductDiscount($DB, $rowid = 0)
    {
        $this->db = $DB;
        if($rowid != 0)
        {
			if($this->fetch($rowid) == 1) return 1 ;
			else return -1;
        }
        else
        {
        	return 1 ;
        }
    }   

	
    /**
     *      \brief      Create in database
     *      \param      user        	User that create
     *      \param      notrigger	    0=launch triggers after, 1=disable triggers
     *      \return     int         	<0 if KO, Id of created object if OK
     */
    function create($user, $notrigger=0)
    {
    	global $conf, $langs;
		$error=0;
    	
		// Clean parameters
        
		if (isset($this->fk_customer)) $this->fk_customer=trim($this->fk_customer);
		if (isset($this->fk_product)) $this->fk_product=trim($this->fk_product);
		if (isset($this->discount)) $this->discount=trim($this->discount);
		if (isset($this->price)) $this->price=trim($this->price);
		if (isset($this->price_base_type)) $this->price_base_type=trim($this->price_base_type);

        

		// Check parameters
		// Put here code to add control on parameters values
		
        // Insert request
		$sql = "INSERT INTO ".MAIN_DB_PREFIX."product_discount(";
		
		$sql.= "fk_customer,";
		$sql.= "fk_product,";
		$sql.= "discount,";
		$sql.= "price,";
		$sql.= "price_base_type";

		
        $sql.= ") VALUES (";
        
		$sql.= " ".(! isset($this->fk_customer)?'NULL':"'".$this->fk_customer."'").",";
		$sql.= " ".(! isset($this->fk_product)?'NULL':"'".$this->fk_product."'").",";
		$sql.= " ".(! isset($this->discount)?'NULL':"'".$this->discount."'").",";
		$sql.= " ".(! isset($this->price)?'NULL':"'".$this->price."'").",";
		$sql.= " ".(! isset($this->price_base_type)?'NULL':"'".addslashes($this->price_base_type)."'")."";

        
		$sql.= ")";

		$this->db->begin();
		
	   	dol_syslog(get_class($this)."::create sql=".$sql, LOG_DEBUG);
        $resql=$this->db->query($sql);
    	if (! $resql) { $error++; $this->errors[]="Error ".$this->db->lasterror(); }
        
		if (! $error)
        {
            $this->id = $this->db->last_insert_id(MAIN_DB_PREFIX."product_discount");
    
			if (! $notrigger)
			{
	            // Uncomment this and change MYOBJECT to your own tag if you
	            // want this action call a trigger.
	            
	            //// Call triggers
	            //include_once(DOL_DOCUMENT_ROOT . "/interfaces.class.php");
	            //$interface=new Interfaces($this->db);
	            //$result=$interface->run_triggers('MYOBJECT_CREATE',$this,$user,$langs,$conf);
	            //if ($result < 0) { $error++; $this->errors=$interface->errors; }
	            //// End call triggers
			}
        }

        // Commit or rollback
        if ($error)
		{
			foreach($this->errors as $errmsg)
			{
	            dol_syslog(get_class($this)."::create ".$errmsg, LOG_ERR);
	            $this->error.=($this->error?', '.$errmsg:$errmsg);
			}	
			$this->db->rollback();
			return -1*$error;
		}
		else
		{
			$this->db->commit();
            return $this->id;
		}
    }

    
    /**
     *    \brief      Load object in memory from database
     *    \param      id          id object
     *    \return     int         <0 if KO, >0 if OK
     */
    function fetch($id, $calculate = true)
    {
    	global $langs;
        $sql = "SELECT";
		$sql.= " t.rowid,";
		
		$sql.= " t.fk_customer,";
		$sql.= " t.fk_product,";
		$sql.= " t.discount,";
		$sql.= " t.price,";
		$sql.= " t.price_base_type";

		
        $sql.= " FROM ".MAIN_DB_PREFIX."product_discount as t";
        $sql.= " WHERE t.rowid = ".$id;
    
    	dol_syslog(get_class($this)."::fetch sql=".$sql, LOG_DEBUG);
        $resql=$this->db->query($sql);
        if ($resql)
        {
            if ($this->db->num_rows($resql))
            {
                $obj = $this->db->fetch_object($resql);
    
                $this->id    = $obj->rowid;
                
				$this->fk_customer = $obj->fk_customer;
				$this->fk_product = $obj->fk_product;
				$this->discount = $obj->discount;
				$this->price = $obj->price;
				$this->price_base_type = $obj->price_base_type;
				
	            //Calculate discount or price
	            if($this->discount == 0 && $calculate)
	            {
	            	$this->calculateDiscount() ;
	            }
	            
	            if($this->price == 0 && $calculate)
	            {
	            	$this->calculatePrice() ;
	            }
	            $this->db->free($resql);
                        
            	return 1 ;           
            }
            else
            {
            	$this->error= $langs->trans('PDErrorLoadingProductDiscount') ;
				dol_syslog(get_class($this)."::fetch ".$this->error, LOG_ERR) ;
				return -1 ;
            }
        }
        else
        {
      	    $this->error="Error ".$this->db->lasterror();
            dol_syslog(get_class($this)."::fetch ".$this->error, LOG_ERR);
            return -1;
        }
    }
        

    /**
     *      \brief      Update database
     *      \param      user        	User that modify
     *      \param      notrigger	    0=launch triggers after, 1=disable triggers
     *      \return     int         	<0 if KO, >0 if OK
     */
    function update($user=0, $notrigger=0)
    {
    	global $conf, $langs;
		$error=0;
    	
		// Clean parameters
        
		if (isset($this->fk_customer)) $this->fk_customer=trim($this->fk_customer);
		if (isset($this->fk_product)) $this->fk_product=trim($this->fk_product);
		if (isset($this->discount)) $this->discount=trim($this->discount);
		if (isset($this->price)) $this->price=trim($this->price);
		if (isset($this->price_base_type)) $this->price_base_type=trim($this->price_base_type);

        

		// Check parameters
		// Put here code to add control on parameters values

        // Update request
        $sql = "UPDATE ".MAIN_DB_PREFIX."product_discount SET";
        
		$sql.= " fk_customer=".(isset($this->fk_customer)?$this->fk_customer:"null").",";
		$sql.= " fk_product=".(isset($this->fk_product)?$this->fk_product:"null").",";
		$sql.= " discount=".(isset($this->discount)?$this->discount:"null").",";
		$sql.= " price=".(isset($this->price)?$this->price:"null").",";
		$sql.= " price_base_type=".(isset($this->price_base_type)?"'".addslashes($this->price_base_type)."'":"null")."";

        
        $sql.= " WHERE rowid=".$this->id;

		$this->db->begin();
        
		dol_syslog(get_class($this)."::update sql=".$sql, LOG_DEBUG);
        $resql = $this->db->query($sql);
    	if (! $resql) { $error++; $this->errors[]="Error ".$this->db->lasterror(); }
        
		if (! $error)
		{
			if (! $notrigger)
			{
	            // Uncomment this and change MYOBJECT to your own tag if you
	            // want this action call a trigger.
				
	            //// Call triggers
	            //include_once(DOL_DOCUMENT_ROOT . "/interfaces.class.php");
	            //$interface=new Interfaces($this->db);
	            //$result=$interface->run_triggers('MYOBJECT_MODIFY',$this,$user,$langs,$conf);
	            //if ($result < 0) { $error++; $this->errors=$interface->errors; }
	            //// End call triggers
	    	}
		}
		
        // Commit or rollback
		if ($error)
		{
			foreach($this->errors as $errmsg)
			{
	            dol_syslog(get_class($this)."::update ".$errmsg, LOG_ERR);
	            $this->error.=($this->error?', '.$errmsg:$errmsg);
			}	
			$this->db->rollback();
			return -1*$error;
		}
		else
		{
			$this->db->commit();
			return 1;
		}		
    }
  
  
 	/**
	 *   \brief      Delete object in database
     *	\param      user        	User that delete
     *   \param      notrigger	    0=launch triggers after, 1=disable triggers
	 *	\return		int				<0 if KO, >0 if OK
	 */
	function delete($user, $notrigger=0)
	{
		global $conf, $langs;
		$error=0;
		
		$sql = "DELETE FROM ".MAIN_DB_PREFIX."product_discount";
		$sql.= " WHERE rowid=".$this->id;
	
		$this->db->begin();
		
		dol_syslog(get_class($this)."::delete sql=".$sql);
		$resql = $this->db->query($sql);
    	if (! $resql) { $error++; $this->errors[]="Error ".$this->db->lasterror(); }
		
		if (! $error)
		{
			if (! $notrigger)
			{
				// Uncomment this and change MYOBJECT to your own tag if you
		        // want this action call a trigger.
				
		        //// Call triggers
		        //include_once(DOL_DOCUMENT_ROOT . "/interfaces.class.php");
		        //$interface=new Interfaces($this->db);
		        //$result=$interface->run_triggers('MYOBJECT_DELETE',$this,$user,$langs,$conf);
		        //if ($result < 0) { $error++; $this->errors=$interface->errors; }
		        //// End call triggers
			}	
		}
		
        // Commit or rollback
		if ($error)
		{
			foreach($this->errors as $errmsg)
			{
	            dol_syslog(get_class($this)."::delete ".$errmsg, LOG_ERR);
	            $this->error.=($this->error?', '.$errmsg:$errmsg);
			}	
			$this->db->rollback();
			return -1*$error;
		}
		else
		{
			$this->db->commit();
			return 1;
		}
	}


	
	/**
	 *		\brief      Load an object from its id and create a new one in database
	 *		\param      fromid     		Id of object to clone
	 * 	 	\return		int				New id of clone
	 */
	function createFromClone($fromid)
	{
		global $user,$langs;
		
		$error=0;
		
		$object=new ProductDiscount($this->db);

		$this->db->begin();

		// Load source object
		$object->fetch($fromid);
		$object->id=0;
		$object->statut=0;

		// Clear fields
		// ...
				
		// Create clone
		$result=$object->create($user);

		// Other options
		if ($result < 0) 
		{
			$this->error=$object->error;
			$error++;
		}
		
		if (! $error)
		{
			
			
			
		}
		
		// End
		if (! $error)
		{
			$this->db->commit();
			return $object->id;
		}
		else
		{
			$this->db->rollback();
			return -1;
		}
	}

	
	/**
	 *		\brief		Initialise object with example values
	 *		\remarks	id must be 0 if object instance is a specimen.
	 */
	function initAsSpecimen()
	{
		$this->id=0;
		
		$this->fk_customer='';
		$this->fk_product='';
		$this->discount='';
		$this->price='';
		$this->price_base_type='';

		
	}
	
	/**
	 * \brief Calculate discount (in percent) from net price (price after discount)
	 */
	function calculateDiscount()
	{
		dol_syslog("ProductDiscount::calculateDiscount()", LOG_DEBUG) ;
		$product = new Product($this->db, $this->fk_product) ;
		
		
		//TODO Chercher constantes pour arrondi + calcul HT / TTC
		$this->discount = round(100*(1 - ($this->price / $product->price)), 4) ;
		
	}
	
	/**
	 * \brief Calculate price (in euros) from discount (in percent)
	 */
	function calculatePrice()
	{
		dol_syslog("ProductDiscount::calculatePrice()", LOG_DEBUG) ;
		$product = new Product($this->db, $this->fk_product) ;
		
		$this->price = price($product->price * (1 - ($this->discount/100))) ;
		
		$this->price_base_type = $product->price_base_type ;
	}


}
?>
