<?php
/* Copyright (C) 2007 Laurent Destailleur  <eldy@users.sourceforge.net>
 * Copyright (C) 2010 Denis Martin  <denimartin@hotmail.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

/**
 *   	\file       htdocs/productdiscount/view_discount.php
 *		\ingroup    productdiscount
 *		\brief      Page to view product-associated discounts
 *		\version    $Id: view_discount.php,v 0.1 13/01/2010 denis Exp $
 *		\author		Denis Martin
 *		\remarks	comments
 */
require("./pre.inc.php");
//require_once(DOL_DOCUMENT_ROOT."/../dev/skeletons/skeleton_class.class.php");

//My includes :
require_once(DOL_DOCUMENT_ROOT."/lib/product.lib.php");
require_once(DOL_DOCUMENT_ROOT."/lib/company.lib.php");
require_once(DOL_DOCUMENT_ROOT."/lib/productdiscount.lib.php") ;

require_once(DOL_DOCUMENT_ROOT."/product.class.php") ;
require_once(DOL_DOCUMENT_ROOT."/societe.class.php") ;
require_once(DOL_DOCUMENT_ROOT."/productdiscount.class.php") ;


// Load traductions files requiredby by page
$langs->load("companies");
$langs->load("other");

//My translation files
$langs->load("products") ;
$langs->load("companies") ;
$langs->load("productdiscount") ;

// Get parameters
$entitytype = isset($_GET["entitytype"]) ? $_GET["entitytype"] : '' ;
$entityid = isset($_GET["id"]) ? $_GET["id"] : '' ;
$entityref = isset($_GET["ref"]) ? $_GET["ref"] : '' ;
$messages = array() ;
$error = array();

// Protection if external user
if ($user->societe_id > 0)
{
	//accessforbidden();
}



/*******************************************************************
* ACTIONS
*
* Put here all code to do according to value of "action" parameter
********************************************************************/


/*
 * After confirmation of the creation
 */
if($_REQUEST['action'] == 'confirm_create')
{
	if($_POST['confirm'] == 'yes')
	{
		if(isset($_GET['prodid']))
		{
			$productdiscount = new ProductDiscount($db) ;
			$productdiscount->fk_customer = $entityid ;
			$productdiscount->fk_product = $_GET['prodid'] ;
			if(isset($_GET['discount']))
			{
				// Creation of the product discount
				$productdiscount->discount = $_GET['discount'] ;	
				$ret = $productdiscount->create($user) ;
				if($ret < 0)
				{
					//Error during the creation in DB
					$error[] = 'PDErrorCreatingPD' ;
				}
				else
				{
					//Product Discount Created
					$messages[] = 'ProductDiscountCreated' ;
				}
			}
			elseif(isset($_GET['price']))
			{
				// Creation of the product discount
				$productdiscount->price = $_GET['price'] ;
				$productdiscount->price_base_type = isset($_GET['price_base_type']) ? $_GET['price_base_type'] : 'HT' ;
				$ret = $productdiscount->create($user) ;
				if($ret < 0)
				{
					//Error during the creation in DB
					$error[] = 'PDErrorCreatingPD' ;
					$error[] = $productdiscount->error ;
					foreach($productdiscount->errors as $err)
					{
						$error[] = $err ;
					}
				}
				else
				{
					//Product Discount Created
					$messages[] = 'ProductDiscountCreated' ;
				}
			}
			else
			{
				//Error : a param is not defined
				$error[] = 'PDErrorParamNotDefined' ;
			}
			
		}
		else
		{
			//Error : a param is not defined
			$error[] = 'PDErrorParamNotDefined' ;
		}
	}
	else
	{
		$messages[] = 'ProductDiscountNotCreated' ;
	}
}

/*
 * After confirmation of the editing
 */
if($_REQUEST['action'] == 'confirm_edit')
{
	if($_POST['confirm'] == 'yes')
	{
		if(isset($_GET['pdid']))
		{
			$productdiscount = new ProductDiscount($db) ;
			if($productdiscount->fetch($_GET['pdid'], false) > 0)
			{
				if(isset($_GET['discount']))
				{
					// Creation of the product discount
					$productdiscount->discount = $_GET['discount'] ;
					unset($productdiscount->price) ;
					unset($productdiscount->price_base_type) ;
					$ret = $productdiscount->update($user) ;
					if($ret < 0)
					{
						//Error during the creation in DB
						$error[] = 'PDErrorEditingPD' ;
					}
					else
					{
						//Product Discount Created
						$messages[] = 'ProductDiscountEdited' ;
					}
				}
				elseif(isset($_GET['price']))
				{
					// Creation of the product discount
					$productdiscount->price = price2num($_GET['price']) ;
					$productdiscount->price_base_type = isset($_GET['price_base_type']) ? $_GET['price_base_type'] : 'HT' ;
					unset($productdiscount->discount) ;
					$ret = $productdiscount->update($user) ;
					if($ret < 0)
					{
						//Error during the creation in DB
						$error[] = 'PDErrorEditingPD' ;
						$error[] = $productdiscount->error ;
						foreach($productdiscount->errors as $err)
						{
							$error[] = $err ;
						}
					}
					else
					{
						//Product Discount Created
						$messages[] = 'ProductDiscountEdited' ;
					}
				}
				else
				{
					//Error : a param is not defined
					$error[] = 'PDErrorParamNotDefined' ;
				}
			}
			else
			{
				$errors[] = 'PDErrorLoadingProductDiscount' ;
			}
			
		}
		else
		{
			//Error : a param is not defined
			$error[] = 'PDErrorParamNotDefined' ;
		}
	}
	else
	{
		$messages[] = 'ProductDiscountNotEdited' ;
	}
}

/*
 * After confirmation of the delete form
 */
if($_REQUEST['action'] == 'confirm_delete')
{
	if($_POST['confirm'] == 'yes')
	{
		if(isset($_GET['pdid']))
		{
			$productdiscount = new ProductDiscount($db) ;
			$productdiscount->id = $_GET['pdid'] ;
			if($productdiscount->delete($user) > 0)
			{
				//Product discount deleted
				$messages[] = 'ProductDiscountDeleted' ;
			}
			else
			{
				//Error : could not delete product discount
				$error[] = 'PDErrorDeletingPD' ;
			}
		}
		else
		{
			//Error : a parameter is not defined
			$error[] = 'PDErrorParamNotDefined' ;
		}
	}
	else
	{
		$messages[] = 'ProductDiscountNotDeleted' ;
	}
}

/***************************************************
* PAGE
*
* Put here all code to build page
****************************************************/

llxHeader('View discounts','','');

$html=new Form($db);


// Put here content of your page
// ...


//If we are viewing discounts of a PRODUCT
if($entitytype == 'product')
{
	//Creating product and getting product details from DB
	$product = new Product($db);

	if ($entityref)
	{
		$result = $product->fetch('',$entityref);
		$entityid = $product->id;
	}
	elseif ($entityid)
	{
		$result = $product->fetch($entityid);
	}
	else
	{
		print 'error' ;
	}

	//Get list of product discount from database
	$array_product_discount = get_product_discount_from_product($product) ;
	
	//Preparation of tabs
	$head=product_prepare_head($product, $user);
	$titre=$langs->trans("CardProduct".$product->type);
	$picto=($product->type==1?'service':'product');
	
	//Displaying of tabs for product card
	dol_fiche_head($head, 'tabProductDiscount', $titre, 0, $picto);
	
	
	//Contents of page: list of discounts
	print '<h3>' . $langs->trans(viewProductDiscountOfProduct) . ' "' . $product->libelle . '".</h3>' . "\n" ;
	

	
	//Table with product details - extract of file htdocs/product/fournisseurs.php l.210
	print '<table class="border" width="100%">';
	
	// Reference display
	print '<tr>';
	print '<td width="15%">'.$langs->trans("Ref").'</td><td colspan="2">';
	print $html->showrefnav($product,'ref','',1,'ref', 'ref', '', '&entitytype=product');
	print '</td>';
	print '</tr>';

	// Label
	print '<tr><td>'.$langs->trans("Label").'</td><td colspan="2">'.$product->libelle.'</td></tr>';

	// Price
	print '<tr><td>'.$langs->trans("SellingPrice").'</td><td colspan="2">';
	if ($product->price_base_type == 'TTC')
	{
		print price($product->price_ttc).' '.$langs->trans($product->price_base_type);
	}
	else
	{
		print price($product->price).' '.$langs->trans($product->price_base_type);
	}
	print '</td></tr>';

	// Status
	print '<tr><td>'.$langs->trans("Status").'</td><td colspan="2">';
	print $product->getLibStatut(2);
	print '</td></tr>';

	//End of table with product details, end of extract from file htdocs/product/fournisseurs.php
	print '</table>';
	
	//End of blue zone
	print '</div>' ;

	// Table with the list of associated product discounts
	print '<table width="100%" class="noborder">' . "\n" ;
	print '<tr class="liste_titre"> <td width="50%">' . $langs->trans("Customer") . '</td> ' ;
	print '<td>' . $langs->trans("UnitaryPrice") . '</td> ' ;
	print '<td>' . $langs->trans("Discount") . '</td> ' ;
	print '<td>' . $langs->trans("NetPrice") . '</td></tr>' ;
	
	//Parity var / gray each two lines
	$parity = "impair" ;
	
	if(count($array_product_discount) == 0)
	{
		print '<tr class="impair"><td colspan="4" align="center"><b>' . $langs->trans('NoProductDiscountFound', $langs->trans("Product")) . '</b></td></tr>' ;
	}
	else
	{
		// Customer that will be fetched for each $product_discount
		$customer = new Societe($db) ;
		
		foreach($array_product_discount as $product_discount)
		{
			
			//Get details of the customer to display
			$customer->fetch($product_discount->fk_customer) ;
			
			//Display the content of the list of product discounts		
			print '<tr class="' . $parity . '">' ;
			print '<td>' . $customer->getNomUrl(1, '', 24) . '</td>' ;
			print '<td>' . price($product->price) . ' &euro;</td>' ;
			print '<td>' . $product_discount->discount . ' %</td>' ;
			print '<td>' . price($product_discount->price) . ' &euro;</td>' ;
			print '</tr>' . "\n" ;
			$parity  = ($parity == "impair" ? "pair" : "impair") ;
		}
	}
	print '</table>' ;
		
}

//If we are viewing discounts of a CUSTOMER
if($entitytype == 'thirdparty')
{
	//Creating thirdparty and getting details from DB
	$societe = new Societe($db);
	$societe->id=$entityid;
	
	if ($entityref)
	{
		$result = $societe->fetch('',$entityref);
		$entityid = $societe->id;
	}
	elseif ($entityid)
	{
		$result = $societe->fetch($entityid);
	}
	else
	{
		print 'error' ;
	}

	//Get list of product discount from database
	$array_product_discount = get_product_discount_from_customer($societe) ;
	
	//Preparation of tabs
	//$head[h][0] = url
	//     [h][1] = 'titre''
	//     [h][2] = code
	$head = societe_prepare_head($societe);
	
	//Displaying of tabs for thirdparty card
	dol_fiche_head($head, 'tabProductDiscount', $langs->trans("ThirdParty"), 0, 'company') ;
	
	
	//Confirmation form to delete a product discount
	if($_GET['action'] == 'delete')
	{
		$productdiscount = new ProductDiscount($db) ;
		if($productdiscount->fetch($_GET['pdid']) == 1) 
		{
			$produit = new Product($db, $productdiscount->fk_product) ;
			$html->form_confirm
			(
				'view_product_discount.php?entitytype=thirdparty&id=' . $societe->id . '&pdid=' . $_GET['pdid'],
				$langs->trans("DeleteProductDiscount"),
				$langs->trans("ConfirmDeleteProductDiscount", $produit->libelle),
				'confirm_delete',
				'',
				1, 1
			) ;
		}
		else
		{
			$error[] = 'PDErrorLoadingProductDiscount' ;
		}
	}
	
		//Error messages
	if(count($error) != 0)
	{
		print '<table width="100%" class="valid">' . "\n" ;
		print '<tr class="valid_titre"><td><strong>' . $langs->trans('Error') . '</strong></td></tr>' ;
		foreach($error as $err)
		{
			print '<tr class="valid"><td>' . $html->textwithpicto($langs->trans($err), 'Erreur', -1, 'warning') . '</td></tr>' ;
			dol_syslog($langs->trans($err), LOG_ERROR) ;
		}
		print '</table>' ;
	}
	
	
	//Confirmation messages (product discount created, or not)
	if(count($messages) != 0)
	{
		print '<table width="100%" class="valid">' . "\n" ;
		print '<tr class="valid_titre"><td><strong>' . $langs->trans('Information') . '</strong></td></tr>' ;
		foreach($messages as $msg)
		{
			print '<tr class="valid"><td>' . $html->textwithpicto($langs->trans($msg), 'Info', -1, 'info') . '</td></tr>' ;
		}
		print '</table>' ;
	}
	
	// On teste si le tiers est bien un client
	if($societe->client)
	{

		//Content of page: discounts of a customer
		print '<h3>' . $langs->trans("viewProductDiscountOfCustomer") . ' "' . $societe->nom . '".</h3>' . "\n" ;
		
		
		//Table détails client, extrait du fichier htdocs/compta/fiche.php; l. 133
		print '<table class="border" width="100%">';
	
		print '<tr><td width="100">'.$langs->trans("Name").'</td><td colspan="3">'.$societe->nom.'</td></tr>';
	
		// Prefix
		print '<tr><td>'.$langs->trans("Prefix").'</td><td colspan="3">';
		print ($societe->prefix_comm?$societe->prefix_comm:'&nbsp;');
		print '</td></tr>';
		
		print '<tr>';
		print '<td nowrap>'.$langs->trans("CustomerCode").'</td><td colspan="3">';
		print $societe->code_client;
		if ($societe->check_codeclient() <> 0) print ' <font class="error">('.$langs->trans("WrongCustomerCode").')</font>';
		print '</td>';
		print '</tr>';

		print '<tr>';
		// TODO Use a html->editfield function
		print '<td><table class="nobordernopadding" width="100%"><tr><td nowrap="nowrap">';
		print $langs->trans("CustomerAccountancyCode");
		print '</td>';
		print '</tr></table>';
		print '</td><td colspan="3">';
		print $societe->code_compta;
		print '</td>';
		print '</tr>';

		print '<tr><td valign="top">'.$langs->trans("Address").'</td><td colspan="3">'.nl2br($societe->adresse)."</td></tr>";

		print '<tr><td>'.$langs->trans('Zip').'</td><td>'.$societe->cp.'</td>';
		print '<td>'.$langs->trans('Town').'</td><td>'.$societe->ville.'</td></tr>';
	
		// Country
		print '<tr><td>'.$langs->trans('Country').'</td><td colspan="3">';
		if ($societe->isInEEC()) print $html->textwithpicto($societe->pays,$langs->trans("CountryIsInEEC"),1,0);
		else print $societe->pays;
		print '</td></tr>';	
		
		// Remise permanente
		print '<tr><td nowrap>';
		print '<table width="100%" class="nobordernopadding"><tr><td nowrap>';
		print $langs->trans("CustomerRelativeDiscountShort");
		print '<td><td align="right">';
		print '</td></tr></table>';
		print '</td><td colspan="3">'.($societe->remise_client?price2num($societe->remise_client,'MT').'%':$langs->trans("DiscountNone")).'</td>';
		print '</tr>';

		// Reductions (Discounts-Drawbacks-Rebates)
		print '<tr><td nowrap>';
		print '<table width="100%" class="nobordernopadding">';
		print '<tr><td nowrap>';
		print $langs->trans("CustomerAbsoluteDiscountShort");
		print '<td><td align="right">';
		print '</td></tr></table>';
		print '</td>';
		print '<td colspan="3">';
		$amount_discount=$societe->getAvailableDiscounts();
		if ($amount_discount < 0) dol_print_error($db,$societe->error);
		if ($amount_discount > 0) print price($amount_discount).'&nbsp;'.$langs->trans("Currency".$conf->monnaie);
		else print $langs->trans("DiscountNone");
		print '</td>';
		print '</tr>';
		
		//Fin table détails client, fin extrait /htdocs/compta/fiche.php
		print '</table>'  . "\n";
		
		//Fin zone centre
		print '</div>' . "\n" ;
		
		// Table with the list of associated product discounts
		print '<table width="100%" class="noborder">' . "\n" ;
		print '<tr class="liste_titre"> <td width="50%">' . $langs->trans("Customer") . '</td> ' . "\n" ;
		print '<td>' . $langs->trans("UnitaryPrice") . '</td> ' . "\n" ;
		print '<td>' . $langs->trans("Discount") . '</td> ' . "\n" ;
		print '<td>' . $langs->trans("NetPrice") . '</td>'  . "\n";
		print '<td>' . $langs->trans("Actions") . '<td></tr>'  . "\n";
		
		//Parity var / gray each two lines
		$parity = "impair" ;
	
		// Product that will be fetched for each $product_discount
		$product = new Product($db) ;
		$paramedit = 'action=edit&id=' ;
		
		if(count($array_product_discount) == 0)
		{
			print '<tr class="impair"><td colspan="5" align="center"><b>' . $langs->trans('NoProductDiscountFound', $langs->trans("Customer")) . '</b></td></tr>' ;
		}
		else
		{
			foreach($array_product_discount as $product_discount)
			{
				
				//Get details of the customer to display
				$product->fetch($product_discount->fk_product) ;
				
				//Display the content of the list of product discounts		
				print '<tr class="' . $parity . '">' . "\n" ;
				print '<td>' . $product->getNomUrl(1, '', 24) . ' - ' . dol_trunc($product->libelle, 70) . '</td>' . "\n" ;
				print '<td>' . price($product->price) . ' &euro;</td>' . "\n" ;
				print '<td>' . $product_discount->discount . ' %</td>' . "\n" ;
				print '<td>' . price($product_discount->price) . ' &euro;</td>' . "\n" ;
				print '<td>' ;
				print '<a href="' . DOL_URL_ROOT . '/productdiscount/edit_product_discount.php?action=edit&socid=' . $societe->id . '&pdid=' . $product_discount->id . '">' . img_edit($langs->trans("EditProductDiscount")) . '</a>&nbsp' ;
				print '<a href="' . DOL_URL_ROOT . '/productdiscount/view_product_discount.php?action=delete&entitytype=thirdparty&id='. $societe->id . '&pdid=' . $product_discount->id . '">' . img_delete($langs->trans("DeleteProductDiscount")) . '</a>';
				print '</td>' . "\n" ;
				print '</tr>' . "\n" ;
				$parity  = ($parity == "impair" ? "pair" : "impair") ;
			}
		}
		
		print '</table>' . "\n" ;
			
		
		print '<div class="tabsAction">' . "\n" ;
		print '<a class="butAction" href="' . DOL_URL_ROOT . '/productdiscount/edit_product_discount.php?socid=' . $societe->id . '">' .$langs->trans('AddProductDiscount') . '</a>' . "\n";
		print '</div>' ;
	
	}
	else
	{
		//Si le tiers n'est pas un client, on n'affiche pas la page.
		print '<h3>' . $langs->trans("thirdIsNotCustomer") . '</h3></div>' ;
	}
	
	
}



// End of page
$db->close();
llxFooter('$Date: 13/01/2010 $ - $Revision: 0.1 $');
?>
